@@ -26,6 +26,10 @@ class RabbitMQConfig(BaseSettings):
     url: str
 
 
+class CORSConfig(BaseSettings):
+    allowed_origin_re: str = ""
+
+
 AnyConfig = TypeVar("AnyConfig", bound=BaseSettings)
 ChloreConfig = TypeVar("ChloreConfig", AuthConfig, DatabaseConfig, LoggingConfig, RabbitMQConfig)
 
@@ -33,6 +37,7 @@ ChloreConfig = TypeVar("ChloreConfig", AuthConfig, DatabaseConfig, LoggingConfig
 @dataclass
 class _InternalConfig:
     auth: AuthConfig = None
+    cors: CORSConfig = None
     logging: LoggingConfig = None
     database: DatabaseConfig = None
     rabbitmq: RabbitMQConfig = None
