@@ -5,7 +5,7 @@ import json
 from pathlib import Path
 import urllib.parse
 
-from fastapi import FastAPI, Cookie, Depends, Header, HTTPException
+from fastapi import FastAPI, Cookie, Depends, Header, HTTPException, params
 from fastapi.requests import Request
 import OpenSSL
 import pydantic
