@@ -2,6 +2,7 @@ from fastapi import Depends, Response
 import jinja2
 
 from chlore.request import get_request
+from chlore.messages import FlashMessages
 
 
 class JinjaResponse(Response):
@@ -29,6 +30,7 @@ def _build_jinja_env(loader: jinja2.BaseLoader) -> jinja2.Environment:
     env = jinja2.Environment(loader=loader, autoescape=True, undefined=jinja2.StrictUndefined)
     env.globals["url_for"] = url_for
     env.globals["static"] = static
+    env.globals["csrf_input"] = ""  # hack, TODO: implement real csrf
     return env
 
 
@@ -76,6 +78,10 @@ def jinja_mixin_with_response_builder(builder: JinjaResponseBuilder):
     """
 
     class _JinjaMixin:
-        render: JinjaResponseBuilder = Depends(lambda: builder)
+        flash: FlashMessages = Depends(FlashMessages)
+
+        def render(self, name: str, context: dict, **kw):
+            context["messages"] = self.flash
+            return builder(name, context, **kw)
 
     return _JinjaMixin
