@@ -1,6 +1,7 @@
 import typing
 from fastapi import Request
 from enum import IntEnum
+from dataclasses import dataclass
 
 
 class FlashType(IntEnum):
@@ -11,6 +12,26 @@ class FlashType(IntEnum):
     ERROR = 4
 
 
+@dataclass
+class UiFlashMessage:
+    "Represent a flash message, with the purpose of rendering in jinja"
+
+    message: str
+    category: FlashType
+
+    @property
+    def bootstrap_classes(self):
+        match self.category:
+            case FlashType.SUCCESS:
+                return "bg-success bg-opacity-50"
+            case FlashType.ERROR:
+                return "bg-danger bg-opacity-50"
+            case FlashType.WARNING:
+                return "bg-warning bg-opacity-50"
+            case _:
+                return ""
+
+
 def add_message(request: Request, category: FlashType, message: str) -> None:
     if "_messages" not in request.session:
         request.session["_messages"] = []
@@ -29,7 +50,7 @@ class FlashMessages:
         return add_message(self.request, category, message)
 
     def pop_all(self):
-        return get_messages(self.request)
+        return [UiFlashMessage(**m) for m in get_messages(self.request)]
 
     def debug(self, message: str):
         self.add(FlashType.DEBUG, message)
